Index: kernel/classes/ezscript.php
===================================================================
--- kernel/classes/ezscript.php	(revision 25282)
+++ kernel/classes/ezscript.php	(working copy)
@@ -171,8 +171,6 @@
     */
     function startup()
     {
-        error_reporting( E_ALL );
-
         eZDebug::setHandleType( eZDebug::HANDLE_TO_PHP );
 
         if ( php_sapi_name() != 'cli' )
Index: runcronjobs.php
===================================================================
--- runcronjobs.php	(revision 25282)
+++ runcronjobs.php	(working copy)
@@ -36,14 +36,7 @@
 // Define maximum script execution time to 12 hours
 define( 'eZRunCronjobs_MaxScriptExecutionTime', 12*3600 );
 
-// Set a default time zone if none is given. The time zone can be overriden
-// in config.php or php.ini.
-if ( !ini_get( "date.timezone" ) )
-{
-    date_default_timezone_set( "UTC" );
-}
-
-require 'autoload.php';
+require 'cli_bootstrap.php';
 require_once( 'kernel/common/i18n.php' );
 
 eZContentLanguage::setCronjobMode();
Index: cli_bootstrap.php
===================================================================
--- cli_bootstrap.php	(revision 0)
+++ cli_bootstrap.php	(revision 0)
@@ -0,0 +1,13 @@
+<?php
+/**
+ * CLI bootstrap
+ *
+ * Specific settings that are used commonly by cli scripts.
+ *
+ * @copyright Copyright (C) 1999-2010 eZ Systems AS. All rights reserved.
+ * @license http://ez.no/licenses/gnu_gpl GNU GPL v2
+ * @version //autogentag//
+ * @package kernel
+ */
+
+require 'bootstrap.php';

Property changes on: cli_bootstrap.php
___________________________________________________________________
Added: svn:eol-style
   + native

Index: autoload.php
===================================================================
--- autoload.php	(revision 25282)
+++ autoload.php	(working copy)
@@ -7,17 +7,12 @@
  *
  */
 
-// config.php can set the components path like:
+// bootstrap.php can set the components path like:
 // ini_set( 'include_path', ini_get( 'include_path' ). ':../ezcomponents/trunk' );
 // It is also possible to push a custom autoload method to the autoload
 // function stack. Remember to check for class prefixes in such a method, if it
 // will not serve classes from eZ Publish and eZ Components
 
-if ( file_exists( 'config.php' ) )
-{
-    require 'config.php';
-}
-
 $useBundledComponents = defined( 'EZP_USE_BUNDLED_COMPONENTS' ) ? EZP_USE_BUNDLED_COMPONENTS === true : file_exists( 'lib/ezc' );
 if ( $useBundledComponents )
 {
Index: ezpm.php
===================================================================
--- ezpm.php	(revision 25282)
+++ ezpm.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'debug-message' => '',
Index: tests/toolkit/extras/scripts/create-test-from-class.php
===================================================================
--- tests/toolkit/extras/scripts/create-test-from-class.php	(revision 25282)
+++ tests/toolkit/extras/scripts/create-test-from-class.php	(working copy)
@@ -8,7 +8,7 @@
  * @package tests
  */
 
-require_once 'autoload.php';
+require_once 'cli_bootstrap.php';
 
 
 class ezpGenerateTestCaseFromClass
Index: tests/runtests.php
===================================================================
--- tests/runtests.php	(revision 25282)
+++ tests/runtests.php	(working copy)
@@ -10,7 +10,7 @@
 
 set_time_limit( 0 );
 
-require_once 'autoload.php';
+require_once 'cli_bootstrap.php';
 
 require_once 'PHPUnit/Framework.php';
 require_once 'PHPUnit/TextUI/TestRunner.php';
Index: bootstrap.php
===================================================================
--- bootstrap.php	(revision 0)
+++ bootstrap.php	(revision 0)
@@ -0,0 +1,133 @@
+<?php
+/**
+ * Common bootstrap file.
+ *
+ * This file contains a documented list of a few configuration points previously
+ * available from config.php. The proposed default values below are meant
+ * to be the most optimized ones, or meaningful examples of what can be achieved.
+ *
+ * @copyright Copyright (C) 1999-2010 eZ Systems AS. All rights reserved.
+ * @license http://ez.no/licenses/gnu_gpl GNU GPL v2
+ * @version //autogentag//
+ * @package kernel
+ */
+
+/*
+    ERROR REPORTING
+    ---------------
+    The error reporting is set to the highest possible level to ensure a strict
+    development practices.
+*/
+error_reporting ( E_ALL | E_STRICT );
+
+
+// Output buffering
+ob_start();
+
+/*
+    TIMEZONES
+    ---------
+    The recommended way of setting timezones is via php.ini.
+    However you can set the default timezone for your eZ Publish application as shown below.
+    More on supported timezones : http://www.php.net/manual/en/timezones.php
+*/
+//date_default_timezone_set( 'Europe/Paris' );
+
+// Set a default time zone if none is given to avoid "It is not safe to rely
+// on the system's timezone settings" warnings.
+if ( !ini_get( "date.timezone" ) )
+{
+    date_default_timezone_set( "UTC" );
+}
+
+ignore_user_abort( true );
+
+/*
+    PATH TO THE EZCOMPONENTS
+    ------------------------
+    Path to the eZ Components can be set like:
+*/
+//ini_set( 'include_path', ini_get( 'include_path' ). PATH_SEPARATOR . '../ezcomponents/trunk' );
+
+/*
+    USING BUNDLED COMPONENTS
+    ------------------------
+    If you are using a distribution of eZ Publish with which the necessary
+    eZ Components are bundled (in lib/ezc), then you can use this setting to
+    control if the bundled eZ Components should be used (true) or not (false).
+    By default, when this setting is not present and the bundled eZ Components are
+    present, they will be used. If you're using the bundled eZ Components it's recommended
+    to define EZP_USE_BUNDLED_COMPONENTS as a boolean true anyway, for optimal speed.
+*/
+//define( 'EZP_USE_BUNDLED_COMPONENTS', true );
+
+
+/*
+    If you are not using the bundled eZ Components, then for optimal speed it is
+    recommended to set EZC_BASE_PATH to either ezc/Base/base.php or Base/src/base.php,
+    depending on how you installed the eZ Components. By default, if this setting
+    is not present, eZ Publish first tries to include ezc/Base/base.php in the standard
+    php include path. If that fails Base/src/base.php is included.
+*/
+//define( 'EZC_BASE_PATH', '/usr/lib/ezc/Base/base.php' );
+
+/*
+    INI FILES OPTIMIZATIONS
+    -----------------------
+    This new setting controls whether eZINI should check if the settings have
+    been updated in the *.ini-files*. If this check is disabled eZ Publish
+    will always used the cached values, lowering the amount of stat-calls to
+    the file system, and thus increasing performance.
+
+    Set EZP_INI_FILEMTIME_CHECK constant to false to improve performance by
+    not checking modified time on ini files. You can also set it to a string, the name
+    of a ini file you still want to check modified time on, best example would be to
+    set it to 'site.ini' to make the system still check that but not the rest.
+*/
+//define( 'EZP_INI_FILEMTIME_CHECK', false );
+
+
+/*
+    KERNEL OVERRIDES
+    ----------------
+    This setting controls if eZ Publish's autoload system should allow, and
+    load classes, which override kernel classes from extensions.
+*/
+//define( 'EZP_AUTOLOAD_ALLOW_KERNEL_OVERRIDE', false );
+
+
+/*
+    Set EZP_INI_FILE_PERMISSION constant to the permissions you want saved
+    ini and cache files to have. This setting also applies to generated autoload files.
+    Do keep an octal number as value here ( meaning it starts by a 0 ).
+*/
+//define( 'EZP_INI_FILE_PERMISSION', 0666 );
+
+
+/*
+    CUSTOM AUTOLOAD MECHANISM
+    -------------------------
+    It is also possible to push a custom autoload method to the autoload
+    function stack. Remember to check for class prefixes in such a method, if it
+    will not serve classes from eZ Publish and eZ Components.
+    Here is an example code snippet to be placed right in this file, in the case
+    you would be using your custom Foo framework, in which all PHP classes would be
+    prefixed by 'Foo' :
+ 
+    <code>
+        ini_set( 'include_path', ini_get( 'include_path' ). ':/usr/lib/FooFramework/' );
+        require 'Foo/ClassLoader.php';
+ 
+        function fooAutoload( $className )
+        {
+           if ( 'Foo' == substr( $className, 0, 3 ) )
+           {
+               FooClassLoader::loadClass( $className );
+           }
+        }
+        spl_autoload_register( 'fooAutoload' );
+    </code>
+*/
+
+require 'autoload.php';
+?>

Property changes on: bootstrap.php
___________________________________________________________________
Added: svn:eol-style
   + native

Index: services_bootstrap.php
===================================================================
--- services_bootstrap.php	(revision 0)
+++ services_bootstrap.php	(revision 0)
@@ -0,0 +1,15 @@
+<?php
+/**
+ * Services bootstrap
+ *
+ * @copyright Copyright (C) 1999-2010 eZ Systems AS. All rights reserved.
+ * @license http://ez.no/licenses/gnu_gpl GNU GPL v2
+ * @version //autogentag//
+ * @package kernel
+ */
+
+require 'bootstrap.php';
+
+// We don't allow services to display possible errors as those need to be
+// handled differently.
+ini_set( "display_errors" , 0 );

Property changes on: services_bootstrap.php
___________________________________________________________________
Added: svn:eol-style
   + native

Index: bin/php/clusterize.php
===================================================================
--- bin/php/clusterize.php	(revision 25282)
+++ bin/php/clusterize.php	(working copy)
@@ -36,10 +36,8 @@
 
 */
 
-error_reporting( E_ALL | E_NOTICE );
+require 'cli_bootstrap.php';
 
-require 'autoload.php';
-
 // This code is taken from eZBinaryFile::storedFileInfo()
 function filePathForBinaryFile($fileName, $mimeType )
 {
Index: bin/php/clusterbinarypurge.php
===================================================================
--- bin/php/clusterbinarypurge.php	(revision 25282)
+++ bin/php/clusterbinarypurge.php	(working copy)
@@ -6,7 +6,7 @@
  * @license http://ez.no/licenses/gnu_gpl GNU GPLv2
  */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish binary files purge\n" .
Index: bin/php/ezsqldumpisbndata.php
===================================================================
--- bin/php/ezsqldumpisbndata.php	(revision 25282)
+++ bin/php/ezsqldumpisbndata.php	(working copy)
@@ -30,7 +30,7 @@
 /*! \file
 */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $fileNameDba = 'db_data.dba';
 $fileNameSql = 'cleandata.sql';
Index: bin/php/ezcsvexport.php
===================================================================
--- bin/php/ezcsvexport.php	(revision 25282)
+++ bin/php/ezcsvexport.php	(working copy)
@@ -32,7 +32,7 @@
 /*! \file
 */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish CSV export script\n" .
Index: bin/php/flatten.php
===================================================================
--- bin/php/flatten.php	(revision 25282)
+++ bin/php/flatten.php	(working copy)
@@ -29,7 +29,7 @@
 
 set_time_limit( 0 );
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $endl = $cli->endlineString();
Index: bin/php/ezcontentcache.php
===================================================================
--- bin/php/ezcontentcache.php	(revision 25282)
+++ bin/php/ezcontentcache.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Content Cache Handler\n" .
Index: bin/php/ezconvertdbcharset.php
===================================================================
--- bin/php/ezconvertdbcharset.php	(revision 25282)
+++ bin/php/ezconvertdbcharset.php	(working copy)
@@ -27,10 +27,9 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 
-
 define( 'EZ_CONTENTCLASS_ATTRIBUTE_TMP_TABLE_NAME', 'ezcontentclass_attribute_tmp' );
 
 define( 'EZ_CREATE_CONTENTCLASS_ATTRIBUTE_TMP_TABLE_SQL_MYSQL',
Index: bin/php/changelog2xmltext.php
===================================================================
--- bin/php/changelog2xmltext.php	(revision 25282)
+++ bin/php/changelog2xmltext.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Changelog converter\n\n" .
Index: bin/php/updatesearchindex.php
===================================================================
--- bin/php/updatesearchindex.php	(revision 25282)
+++ bin/php/updatesearchindex.php	(working copy)
@@ -29,7 +29,7 @@
 
 set_time_limit( 0 );
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $endl = $cli->endlineString();
Index: bin/php/ezsqlinsertschema.php
===================================================================
--- bin/php/ezsqlinsertschema.php	(revision 25282)
+++ bin/php/ezsqlinsertschema.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish SQL Schema insert\n\n" .
Index: bin/php/eztc.php
===================================================================
--- bin/php/eztc.php	(revision 25282)
+++ bin/php/eztc.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Template Compiler\n" .
Index: bin/php/ezsqldumpschema.php
===================================================================
--- bin/php/ezsqldumpschema.php	(revision 25282)
+++ bin/php/ezsqldumpschema.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish SQL Schema dump\n\n" .
Index: bin/php/makestaticcache.php
===================================================================
--- bin/php/makestaticcache.php	(revision 25282)
+++ bin/php/makestaticcache.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish static cache generator\n" .
Index: bin/php/ezwebinupgrade.php
===================================================================
--- bin/php/ezwebinupgrade.php	(revision 25282)
+++ bin/php/ezwebinupgrade.php	(working copy)
@@ -42,7 +42,7 @@
 /*!
  includes
 */
-require 'autoload.php';
+require 'cli_bootstrap.php';
 include_once( 'bin/php/ezwebincommon.php' );
 
 
Index: bin/php/ezwebincommon.php
===================================================================
--- bin/php/ezwebincommon.php	(revision 25282)
+++ bin/php/ezwebincommon.php	(working copy)
@@ -46,7 +46,7 @@
 /*!
  includes
 */
-require_once 'autoload.php';
+require_once 'cli_bootstrap.php';
 
 /**************************************************************
 * 'cli->output' wrappers                                      *
Index: bin/php/ezflowupgrade.php
===================================================================
--- bin/php/ezflowupgrade.php	(revision 25282)
+++ bin/php/ezflowupgrade.php	(working copy)
@@ -42,7 +42,7 @@
 /*!
  includes
 */
-require 'autoload.php';
+require 'cli_bootstrap.php';
 include_once( 'bin/php/ezwebincommon.php' );
 
 
Index: bin/php/ezconvertmysqltabletype.php
===================================================================
--- bin/php/ezconvertmysqltabletype.php	(revision 25282)
+++ bin/php/ezconvertmysqltabletype.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Database Converter\n\n" .
Index: bin/php/ezcheckphptag.php
===================================================================
--- bin/php/ezcheckphptag.php	(revision 25282)
+++ bin/php/ezcheckphptag.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish PHP tag checker\n\n" .
Index: bin/php/adddefaultstates.php
===================================================================
--- bin/php/adddefaultstates.php	(revision 25282)
+++ bin/php/adddefaultstates.php	(working copy)
@@ -1,7 +1,7 @@
 #!/usr/bin/env php
 <?php
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: bin/php/ezexec.php
===================================================================
--- bin/php/ezexec.php	(revision 25282)
+++ bin/php/ezexec.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Script Executor\n\n" .
Index: bin/php/ezpgenerateautoloads.php
===================================================================
--- bin/php/ezpgenerateautoloads.php	(revision 25282)
+++ bin/php/ezpgenerateautoloads.php	(working copy)
@@ -25,10 +25,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-if ( file_exists( "config.php" ) )
-{
-    require "config.php";
-}
+require "cli_bootstrap.php";
 
 // Setup, includes
 //{
Index: bin/php/ezsqldiff.php
===================================================================
--- bin/php/ezsqldiff.php	(revision 25282)
+++ bin/php/ezsqldiff.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish SQL diff\n\n" .
Index: bin/php/ezwebininstall.php
===================================================================
--- bin/php/ezwebininstall.php	(revision 25282)
+++ bin/php/ezwebininstall.php	(working copy)
@@ -44,7 +44,7 @@
  includes
 */
 include_once( 'bin/php/ezwebincommon.php' );
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 // script initializing
 $cli = eZCLI::instance();
Index: bin/php/ezchecktranslation.php
===================================================================
--- bin/php/ezchecktranslation.php	(revision 25282)
+++ bin/php/ezchecktranslation.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Translation Checker\n\n" .
Index: bin/php/ezsessiongc.php
===================================================================
--- bin/php/ezsessiongc.php	(revision 25282)
+++ bin/php/ezsessiongc.php	(working copy)
@@ -30,7 +30,7 @@
 set_time_limit( 0 );
 $isQuiet = false;
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Session Garbage Collector\n\n" .
Index: bin/php/ezgeneratetranslationcache.php
===================================================================
--- bin/php/ezgeneratetranslationcache.php	(revision 25282)
+++ bin/php/ezgeneratetranslationcache.php	(working copy)
@@ -35,7 +35,7 @@
 * script initializing                                         *
 ***************************************************************/
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "\n" .
Index: bin/php/ezcache.php
===================================================================
--- bin/php/ezcache.php	(revision 25282)
+++ bin/php/ezcache.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Cache Handler\n" .
Index: bin/php/updateisbn13.php
===================================================================
--- bin/php/updateisbn13.php	(revision 25282)
+++ bin/php/updateisbn13.php	(working copy)
@@ -33,7 +33,7 @@
          calculate the length of Registration group, Registrant and Publication element.
  */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 
 $fileAdded = false;
Index: bin/php/ezsubtreecopy.php
===================================================================
--- bin/php/ezsubtreecopy.php	(revision 25282)
+++ bin/php/ezsubtreecopy.php	(working copy)
@@ -31,7 +31,7 @@
 // file  bin/php/ezsubtreecopy.php
 
 // script initializing
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "\n" .
Index: bin/php/checkdbfiles.php
===================================================================
--- bin/php/checkdbfiles.php	(revision 25282)
+++ bin/php/checkdbfiles.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish DB file verifier\n\n" .
Index: bin/php/eztemplatecheck.php
===================================================================
--- bin/php/eztemplatecheck.php	(revision 25282)
+++ bin/php/eztemplatecheck.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Template Syntax Checker\n" .
Index: bin/php/convertezenumtoezselection.php
===================================================================
--- bin/php/convertezenumtoezselection.php	(revision 25282)
+++ bin/php/convertezenumtoezselection.php	(working copy)
@@ -25,7 +25,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: bin/php/ezimportdbafile.php
===================================================================
--- bin/php/ezimportdbafile.php	(revision 25282)
+++ bin/php/ezimportdbafile.php	(working copy)
@@ -30,7 +30,7 @@
 /*! \file
 */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish datatype sql update\n\n" .
Index: bin/php/ezapplytemplate.php
===================================================================
--- bin/php/ezapplytemplate.php	(revision 25282)
+++ bin/php/ezapplytemplate.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Code Template Generator\n\n" .
Index: bin/php/ezconvert2isbn13.php
===================================================================
--- bin/php/ezconvert2isbn13.php	(revision 25282)
+++ bin/php/ezconvert2isbn13.php	(working copy)
@@ -56,7 +56,7 @@
 
 set_time_limit( 0 );
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish ISBN-10 to ISBN-13 converter\n\n" .
Index: bin/php/convertprice2multiprice.php
===================================================================
--- bin/php/convertprice2multiprice.php	(revision 25282)
+++ bin/php/convertprice2multiprice.php	(working copy)
@@ -39,7 +39,7 @@
 
 
 // script initializing
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 global $cli;
 global $currencyList;
Index: bin/php/ezcsvimport.php
===================================================================
--- bin/php/ezcsvimport.php	(revision 25282)
+++ bin/php/ezcsvimport.php	(working copy)
@@ -32,7 +32,7 @@
 /*! \file
 */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish CSV import script\n\n" .
Index: bin/php/ezsubtreeremove.php
===================================================================
--- bin/php/ezsubtreeremove.php	(revision 25282)
+++ bin/php/ezsubtreeremove.php	(working copy)
@@ -31,7 +31,7 @@
 // file  bin/php/ezsubtreeremove.php
 
 // script initializing
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "\n" .
Index: bin/php/updateniceurls.php
===================================================================
--- bin/php/updateniceurls.php	(revision 25282)
+++ bin/php/updateniceurls.php	(working copy)
@@ -34,7 +34,7 @@
 
 set_time_limit ( 0 );
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish url-alias imported and updater.\n\n" .
                                                          "Will import urls from the older (3.9) system into the new, controlled by the --import* options.\n" .
Index: config.php-RECOMMENDED
===================================================================
--- config.php-RECOMMENDED	(revision 25282)
+++ config.php-RECOMMENDED	(working copy)
@@ -1,112 +0,0 @@
-<?php
-/*
-   WHAT THIS FILE IS ABOUT - READ CAREFULLY
-   ----------------------------------------
-   This file contains a documented list of the few configuration points
-   available from config.php. The proposed default values below are meant
-   to be the most optimized ones, or meaningful examples of what can be achieved.
-
-   In order to have the present settings taken into account, you will need to
-   rename this file into config.php, and keep it placed at the root of eZ Publish,
-   where config.php-RECOMMENDED is currently placed. Plus, you will need to
-   *uncomment* the proposed settings.
-*/
-
-
-/*
-   PATH TO THE EZCOMPONENTS
-   ------------------------
-   config.php can set the components path like:
-*/
-//ini_set( 'include_path', ini_get( 'include_path' ). PATH_SEPARATOR . '../ezcomponents/trunk' );
-
-/*
-    USING BUNDLED COMPONENTS
-    ------------------------
-    If you are using a distribution of eZ Publish with which the necessary
-    eZ Components are bundled (in lib/ezc), then you can use this setting to
-    control if the bundled eZ Components should be used (true) or not (false).
-    By default, when this setting is not present and the bundled eZ Components are
-    present, they will be used. If you're using the bundled eZ Components it's recommended
-    to define EZP_USE_BUNDLED_COMPONENTS as a boolean true anyway, for optimal speed.
-*/
-//define( 'EZP_USE_BUNDLED_COMPONENTS', true );
-
-
-/*
-   If you are not using the bundled eZ Components, then for optimal speed it is
-   recommended to set EZC_BASE_PATH to either ezc/Base/base.php or Base/src/base.php,
-   depending on how you installed the eZ Components. By default, if this setting
-   is not present, eZ Publish first tries to include ezc/Base/base.php in the standard
-   php include path. If that fails Base/src/base.php is included.
-*/
-//define( 'EZC_BASE_PATH', '/usr/lib/ezc/Base/base.php' );
-
-/*
-   TIMEZONES
-   ---------
-   The recommended way of setting timezones is via php.ini.
-   However you can set the default timezone for your eZ Publish application as shown below.
-   More on supported timezones : http://www.php.net/manual/en/timezones.php
-*/
-//date_default_timezone_set( 'Europe/Paris' );
-
-/*
-    INI FILES OPTIMIZATIONS
-    -----------------------
-    This new setting controls whether eZINI should check if the settings have
-    been updated in the *.ini-files*. If this check is disabled eZ Publish
-    will always used the cached values, lowering the amount of stat-calls to
-    the file system, and thus increasing performance.
-
-    Set EZP_INI_FILEMTIME_CHECK constant to false to improve performance by
-    not checking modified time on ini files. You can also set it to a string, the name
-    of a ini file you still want to check modified time on, best example would be to
-    set it to 'site.ini' to make the system still check that but not the rest.
-*/
-//define( 'EZP_INI_FILEMTIME_CHECK', false );
-
-
-/*
-    KERNEL OVERRIDES
-    ----------------
-    This setting controls if eZ Publish's autoload system should allow, and
-    load classes, which override kernel classes from extensions.
-*/
-//define( 'EZP_AUTOLOAD_ALLOW_KERNEL_OVERRIDE', false );
-
-
-/*
-    Set EZP_INI_FILE_PERMISSION constant to the permissions you want saved
-    ini and cache files to have. This setting also applies to generated autoload files.
-    Do keep an octal number as value here ( meaning it starts by a 0 ).
-*/
-//define( 'EZP_INI_FILE_PERMISSION', 0666 );
-
-
-
-/*
-   CUSTOM AUTOLOAD MECHANISM
-   -------------------------
-   It is also possible to push a custom autoload method to the autoload
-   function stack. Remember to check for class prefixes in such a method, if it
-   will not serve classes from eZ Publish and eZ Components.
-   Here is an example code snippet to be placed right in this file, in the case
-   you would be using your custom Foo framework, in which all PHP classes would be
-   prefixed by 'Foo' :
-
-   <code>
-       ini_set( 'include_path', ini_get( 'include_path' ). ':/usr/lib/FooFramework/' );
-       require 'Foo/ClassLoader.php';
-
-       function fooAutoload( $className )
-       {
-          if ( 'Foo' == substr( $className, 0, 3 ) )
-          {
-              FooClassLoader::loadClass( $className );
-          }
-       }
-       spl_autoload_register( 'fooAutoload' );
-   </code>
-*/
-?>
Index: update/common/scripts/4.0/updatevatcountries.php
===================================================================
--- update/common/scripts/4.0/updatevatcountries.php	(revision 25282)
+++ update/common/scripts/4.0/updatevatcountries.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish Country update script\n\n" .
Index: update/common/scripts/4.0/updatebinaryfile.php
===================================================================
--- update/common/scripts/4.0/updatebinaryfile.php	(revision 25282)
+++ update/common/scripts/4.0/updatebinaryfile.php	(working copy)
@@ -29,7 +29,7 @@
  \file
 */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.0/updatetipafriendpolicy.php
===================================================================
--- update/common/scripts/4.0/updatetipafriendpolicy.php	(revision 25282)
+++ update/common/scripts/4.0/updatetipafriendpolicy.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/updateimagesystem.php
===================================================================
--- update/common/scripts/4.1/updateimagesystem.php	(revision 25282)
+++ update/common/scripts/4.1/updateimagesystem.php	(working copy)
@@ -25,7 +25,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/correctxmlalign.php
===================================================================
--- update/common/scripts/4.1/correctxmlalign.php	(revision 25282)
+++ update/common/scripts/4.1/correctxmlalign.php	(working copy)
@@ -38,7 +38,7 @@
     exit;
 }
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/addlockstategroup.php
===================================================================
--- update/common/scripts/4.1/addlockstategroup.php	(revision 25282)
+++ update/common/scripts/4.1/addlockstategroup.php	(working copy)
@@ -1,7 +1,7 @@
 #!/usr/bin/env php
 <?php
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/fixezurlobjectlinks.php
===================================================================
--- update/common/scripts/4.1/fixezurlobjectlinks.php	(revision 25282)
+++ update/common/scripts/4.1/fixezurlobjectlinks.php	(working copy)
@@ -9,7 +9,7 @@
  *
  */
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 set_time_limit( 0 );
 
Index: update/common/scripts/4.1/fixclassremoteid.php
===================================================================
--- update/common/scripts/4.1/fixclassremoteid.php	(revision 25282)
+++ update/common/scripts/4.1/fixclassremoteid.php	(working copy)
@@ -34,7 +34,7 @@
     }
 }
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/fixnoderemoteid.php
===================================================================
--- update/common/scripts/4.1/fixnoderemoteid.php	(revision 25282)
+++ update/common/scripts/4.1/fixnoderemoteid.php	(working copy)
@@ -34,7 +34,7 @@
  }
 }
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/fixobjectremoteid.php
===================================================================
--- update/common/scripts/4.1/fixobjectremoteid.php	(revision 25282)
+++ update/common/scripts/4.1/fixobjectremoteid.php	(working copy)
@@ -34,7 +34,7 @@
     }
 }
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.1/initurlaliasmlid.php
===================================================================
--- update/common/scripts/4.1/initurlaliasmlid.php	(revision 25282)
+++ update/common/scripts/4.1/initurlaliasmlid.php	(working copy)
@@ -1,7 +1,7 @@
 #!/usr/bin/env php
 <?php
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 
Index: update/common/scripts/4.2/fixorphanimages.php
===================================================================
--- update/common/scripts/4.2/fixorphanimages.php	(revision 25282)
+++ update/common/scripts/4.2/fixorphanimages.php	(working copy)
@@ -24,7 +24,7 @@
 //
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "Fixes eZImageAliasHandler bug (http://issues.ez.no/15155)" ),
Index: update/common/scripts/4.3/updatenodeassignment.php
===================================================================
--- update/common/scripts/4.3/updatenodeassignment.php	(revision 25282)
+++ update/common/scripts/4.3/updatenodeassignment.php	(working copy)
@@ -132,7 +132,7 @@
     }
 }
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 $script = eZScript::instance( array( 'description' => "eZ Publish node assignment update script. " .
                                            "This script will clean up unused node assignment entries because of bug 15478: " .
                                            "node assignment is not removed when removing node from child list",
Index: update/common/scripts/updatecontentobjectname.php
===================================================================
--- update/common/scripts/updatecontentobjectname.php	(revision 25282)
+++ update/common/scripts/updatecontentobjectname.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 set_time_limit( 0 );
 
Index: update/common/scripts/cleanup.php
===================================================================
--- update/common/scripts/cleanup.php	(revision 25282)
+++ update/common/scripts/cleanup.php	(working copy)
@@ -27,7 +27,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-require 'autoload.php';
+require 'cli_bootstrap.php';
 
 set_time_limit( 0 );
 
Index: soap.php
===================================================================
--- soap.php	(revision 25282)
+++ soap.php	(working copy)
@@ -35,19 +35,8 @@
   SOAP functions are
 */
 
-ob_start();
+require 'services_bootstrap.php';
 
-ini_set( "display_errors" , "0" );
-
-// Set a default time zone if none is given. The time zone can be overriden
-// in config.php or php.ini.
-if ( !ini_get( "date.timezone" ) )
-{
-    date_default_timezone_set( "UTC" );
-}
-
-require 'autoload.php';
-
 /*!
  Reads settings from site.ini and passes them to eZDebug.
 */
Index: index.php
===================================================================
--- index.php	(revision 25282)
+++ index.php	(working copy)
@@ -33,20 +33,9 @@
     exit;
 }
 
-// Set a default time zone if none is given to avoid "It is not safe to rely
-// on the system's timezone settings" warnings. The time zone can be overriden
-// in config.php or php.ini.
-if ( !ini_get( "date.timezone" ) )
-{
-    date_default_timezone_set( "UTC" );
-}
+require 'bootstrap.php';
 
-require 'autoload.php';
-
-ignore_user_abort( true );
-
 $scriptStartTime = microtime( true );
-ob_start();
 
 $use_external_css = true;
 $show_page_layout = true;
@@ -86,9 +75,6 @@
 $GLOBALS['eZSiteBasics'] =& $siteBasics;
 
 $GLOBALS['eZRedirection'] = false;
-
-error_reporting ( E_ALL | E_STRICT );
-
 $debugINI = eZINI::instance( 'debug.ini' );
 eZDebugSetting::setDebugINI( $debugINI );
 
Index: webdav.php
===================================================================
--- webdav.php	(revision 25282)
+++ webdav.php	(working copy)
@@ -28,22 +28,8 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-// Set a default time zone if none is given. The time zone can be overriden
-// in config.php or php.ini.
-if ( !ini_get( "date.timezone" ) )
-{
-    date_default_timezone_set( "UTC" );
-}
+require 'services_bootstrap.php';
 
-require 'autoload.php';
-
-ignore_user_abort( true );
-ob_start();
-
-ini_set( "display_errors" , "0" );
-
-error_reporting ( E_ALL );
-
 // Turn off session stuff, isn't needed for WebDAV operations.
 $GLOBALS['eZSiteBasics']['session-required'] = false;
 
Index: index_image.php
===================================================================
--- index_image.php	(revision 25282)
+++ index_image.php	(working copy)
@@ -22,5 +22,6 @@
 
 if ( !defined( 'STORAGE_BACKEND' ) )
     die( "No storage backend chosen.\n" );
-include_once( 'index_image_' . STORAGE_BACKEND . '.php' );
+require 'services_bootstrap.php';
+require 'index_image_' . STORAGE_BACKEND . '.php';
 ?>
Index: index_treemenu.php
===================================================================
--- index_treemenu.php	(revision 25282)
+++ index_treemenu.php	(working copy)
@@ -24,12 +24,7 @@
 // ## END COPYRIGHT, LICENSE AND WARRANTY NOTICE ##
 //
 
-// Set a default time zone if none is given. The time zone can be overriden
-// in config.php or php.ini.
-if ( !ini_get( 'date.timezone' ) )
-{
-    date_default_timezone_set( 'UTC' );
-}
+require 'services_bootstrap.php';
 
 define( 'MAX_AGE', 86400 );
 
@@ -42,14 +37,13 @@
     exit();
 }
 
-require 'autoload.php';
 require 'lib/ezutils/classes/ezsession.php';
 require 'kernel/common/ezincludefunctions.php';
 
 // Tweaks ini filetime checks if not defined!
 // This makes ini system not check modified time so
 // that index_treemenu.php can assume that index.php does
 // this regular enough, set in config.php to override.
 if ( !defined('EZP_INI_FILEMTIME_CHECK') )
 {
     define( 'EZP_INI_FILEMTIME_CHECK', false );
@@ -71,10 +65,6 @@
     eZExecution::setCleanExit();
 }
 
-ignore_user_abort( true );
-ob_start();
-error_reporting ( E_ALL );
-
 eZExecution::addFatalErrorHandler( 'eZFatalError' );
 eZDebug::setHandleType( eZDebug::HANDLE_FROM_PHP );
 
@@ -42,14 +37,13 @@
 // This makes ini system not check modified time so
 // that index_treemenu.php can assume that index.php does
-// this regular enough, set in config.php to override.
+// this regular enough, set in bootstrap.php to override.
 if ( !defined('EZP_INI_FILEMTIME_CHECK') )
 {
